@@ -20,9 +20,8 @@ from kazoo.client import KazooClient
 
 # TODO use local backup for ZK if server unavailable
 
+logging.getLogger('kazoo.client').setLevel('WARNING')
 logger = logging.getLogger(__name__)
-logger.addHandler(logging.NullHandler())
-logger.setLevel(logging.DEBUG)
 
 # preserve order of keys in dict
 yaml.add_representer(
